package com.demoad.plugin_codelab.adhelper.ads;

import static androidx.lifecycle.Lifecycle.Event.ON_START;

import android.app.Activity;
import android.app.Application;
import android.os.Bundle;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.lifecycle.LifecycleObserver;
import androidx.lifecycle.OnLifecycleEvent;
import androidx.lifecycle.ProcessLifecycleOwner;

import com.demoad.plugin_codelab.ASDK.BaseApp;
import com.demoad.plugin_codelab.adhelper.helpers.SharedPreferencesClass;
import com.demoad.plugin_codelab.adhelper.utils.Pack5AdsPreferenceClass;
import com.demoad.plugin_codelab.adhelper.utils.Pack5AdsUtils;
import com.google.android.gms.ads.AdError;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.FullScreenContentCallback;
import com.google.android.gms.ads.LoadAdError;
import com.google.android.gms.ads.appopen.AppOpenAd;

public class Pack5AppOpenAds implements LifecycleObserver, Application.ActivityLifecycleCallbacks {
    public static AppOpenAd pack5appOpenAd = null;
    private static boolean isShowingAd = false;
    private BaseApp myApplication;
    private AppOpenAd.AppOpenAdLoadCallback loadCallback;
    private Activity currentActivity;


    public Pack5AppOpenAds(BaseApp myApplication) {
        this.myApplication = myApplication;
        this.myApplication.registerActivityLifecycleCallbacks(this);
        ProcessLifecycleOwner.get().getLifecycle().addObserver(this);
    }

    @OnLifecycleEvent(ON_START)
    public void onStart() {
        showAdIfAvailable();
        Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads ==> onStart");
    }

    public void showAdIfAvailable() {

        if (Pack5AdsPreferenceClass.getAllAdEnable() != 1) {
            return;
        }
        if (Pack5AdsPreferenceClass.getEnableOpenad() != 1) {
            return;
        }


        if (Pack5AdsUtils.isShowingFullScreenAd) {
            return;
        }
        if (isShowingAd) {
            return;
        }


        if (pack5appOpenAd != null && !SharedPreferencesClass.getInstance().getBoolean("isSplash", true)) {
            Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads ==> Will show ad.");
            FullScreenContentCallback callback = new FullScreenContentCallback() {
                @Override
                public void onAdDismissedFullScreenContent() {
                    Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads ==> onAdDismissedFullScreenContent");
                    Pack5AdsUtils.isShowingFullScreenAd = false;
                    pack5appOpenAd = null;
                    isShowingAd = false;
                    fetchAd();
                }

                @Override
                public void onAdFailedToShowFullScreenContent(@NonNull AdError adError) {
                    Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads ==> onAdFailedToShowFullScreenContent \n" + adError.getMessage());
                    Pack5AdsUtils.isShowingFullScreenAd = false;
                    pack5appOpenAd = null;
                    isShowingAd = false;
                    fetchAd();
                }

                @Override
                public void onAdShowedFullScreenContent() {
                    Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads ==> onAdShowedFullScreenContent");
                    Pack5AdsUtils.isShowingFullScreenAd = true;
                    isShowingAd = true;
                }
            };

            pack5appOpenAd.setFullScreenContentCallback(callback);

            pack5appOpenAd.show(currentActivity);
            int count = Pack5AdsUtils.getOpenAdsShowedCount();
            Pack5AdsUtils.setOpenAdsShowedCount(count + 1);
            Pack5AdsUtils.isShowingFullScreenAd = true;
            isShowingAd = true;
        } else {
            Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads ==> Can not show ad.");
            fetchAd();
        }
    }

    public void fetchAd() {
        if (Pack5AdsPreferenceClass.getAllAdEnable() != 1) {
            return;
        }
        if (Pack5AdsPreferenceClass.getEnableOpenad() != 1) {
            return;
        }

        if (isShowingAd) {
            return;
        }
        if (Pack5AdsUtils.isShowingFullScreenAd) {
            return;
        }
        if (pack5appOpenAd != null) {
            return;
        }

        int showCount = Pack5AdsUtils.getOpenAdsShowedCount();
        int totalLimit = Pack5AdsPreferenceClass.getAppOpenCount();
        if (showCount >= totalLimit) {
            Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads Limit Exist ==> ShowCount: " + showCount + "  TotalLimit: " + totalLimit);
            return;
        }


        if (pack5appOpenAd == null) {
            loadCallback = new AppOpenAd.AppOpenAdLoadCallback() {

                @Override
                public void onAdLoaded(@NonNull AppOpenAd ad) {
                    pack5appOpenAd = ad;
                    Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads ==> onAdLoaded");
                }


                @Override
                public void onAdFailedToLoad(@NonNull LoadAdError loadAdError) {
                    Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "AppOpen Ads ==> onAdFailedToLoad" + loadAdError.getMessage());
                    Pack5AdsUtils.isShowingFullScreenAd = false;
                }

            };


            String adUnitId = "";

            if (Pack5AdsPreferenceClass.getAdtype().equalsIgnoreCase(Pack5AdsUtils.ADMOB)) {
                adUnitId = Pack5AdsPreferenceClass.getAdmobOpenadId();
                if (adUnitId.isEmpty()) {
                    adUnitId = Pack5AdsPreferenceClass.getAdxOpenadId();
                }
            } else if (Pack5AdsPreferenceClass.getAdtype().equalsIgnoreCase(Pack5AdsUtils.ADX)) {
                adUnitId = Pack5AdsPreferenceClass.getAdxOpenadId();
            } else return;

            if (adUnitId == null) {
                return;
            }

            if (adUnitId.isEmpty()) {
                return;
            }

            Log.e(Pack5AdManager.PACK5_ADMOB_TAG, "Load Open App Manager id: " + adUnitId);
            AppOpenAd.load(myApplication, adUnitId, new AdRequest.Builder().build(), AppOpenAd.APP_OPEN_AD_ORIENTATION_PORTRAIT, loadCallback);
        }
    }

    @Override
    public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
    }

    @Override
    public void onActivityStarted(Activity activity) {
        currentActivity = activity;
    }

    @Override
    public void onActivityResumed(Activity activity) {
        currentActivity = activity;
    }

    @Override
    public void onActivityStopped(Activity activity) {
    }

    @Override
    public void onActivityPaused(Activity activity) {
    }

    @Override
    public void onActivitySaveInstanceState(Activity activity, Bundle bundle) {
    }

    @Override
    public void onActivityDestroyed(Activity activity) {
        currentActivity = null;
    }

}